import { useState } from 'react'
import { getDictType, getDictTypeNoAuth } from '@/api/services/common'

/**
 * 使用方式:
 *   1. import useDict from '@/hooks/useDict'
 *   2. const { dictArray: contractTypeDict, dictRequestFn: getContractTypeDict } = useDict('contract_type')
 * @param dictType 字典接口入参type
 * @return {{dictRequestFn: dictRequestFn, dictArray: ToRef<*[]>}} 返回: 1.字典数组 2.获取字典的请求函数
 */
export default function useDict(dictType: string) {
  // 定义字典数组
  const [dictArray, setDictArray] = useState<API.DictItem[]>([])
  // 获取字典
  const dictRequestFn = async () => {
    const res = await getDictType({ type: dictType })
    if (res?.code === '2000') {
      setDictArray(res.data)
    }
  }
  return {
    dictArray,
    dictRequestFn
  }
}

// 不需要鉴权的字典, 使用方式 import { useNoAuthDict } from '@/hooks/useDict' 同上
export function useNoAuthDict(dictType: string) {
  // 定义字典数组
  const [dictArray, setDictArray] = useState<any[]>([])
  // 获取字典
  const dictRequestFn = async () => {
    const res = await getDictTypeNoAuth({ type: dictType })
    if (res?.code === '2000') {
      setDictArray(res.data)
    }
  }
  return {
    dictArray,
    dictRequestFn
  }
}

/**
 * 映射字典
 * @param dict 字典内容
 * @param row 映射的对象
 * @param attr 映射的对象属性
 * @return 映射后的值
 */
export function dictMapping<T extends Record<string, any>, K extends keyof T>(
  row: T,
  attr: K,
  dict: any[],
  label: string = 'label',
  value: string = 'itemValue'
) {
  let val
  for (let i = 0; i < dict.length; i++) {
    if (dict[i][value] === row[attr]) {
      val = dict[i][label]
      break
    }
  }
  return val
}
